@@ -205,22 +205,30 @@ class WorkflowRuntimeServer:
 
         self.operate()
 
-    async def stop(self, reason):
-        """Stop the TCP servers, and clean up authentication."""
+    async def stop(self, reason: Union[BaseException, str]) -> None:
+        """Stop the TCP servers, and clean up authentication.
+
+        This method must be called/awaited from a different thread to the
+        server's self.thread in order to interrupt the self.operate() loop
+        and wait for self.thread to terminate.
+        """
         self.queue.put('STOP')
         if self.thread and self.thread.is_alive():
             while not self.stopping:
-                # Non-async sleep - yield to other threads rather
-                # than event loop.
+                # Non-async sleep - yield to other threads rather than
+                # event loop (allows self.operate() running in different
+                # thread to return)
                 sleep(self.STOP_SLEEP_INTERVAL)
 
         if self.replier:
             self.replier.stop(stop_loop=False)
         if self.publisher:
+            await self.publish_queued_items()
             await self.publisher.publish(
                 [(b'shutdown', str(reason).encode('utf-8'))]
             )
             self.publisher.stop(stop_loop=False)
+            self.publisher = None
         if self.curve_auth:
             self.curve_auth.stop()  # stop the authentication thread
         if self.loop and self.loop.is_running():
@@ -230,8 +238,11 @@ class WorkflowRuntimeServer:
 
         self.stopped = True
 
-    def operate(self):
+    def operate(self) -> None:
         """Orchestrate the receive, send, publish of messages."""
+        # Note: this cannot be an async method because the response part
+        # of the listener runs the event loop synchronously
+        # (in graphql AsyncioExecutor)
         while True:
             # process messages from the scheduler.
             if self.queue.qsize():
@@ -243,15 +254,18 @@ class WorkflowRuntimeServer:
 
             # Gather and respond to any requests.
             self.replier.listener()
-
             # Publish all requested/queued.
-            while self.publish_queue.qsize():
-                articles = self.publish_queue.get()
-                self.loop.run_until_complete(self.publisher.publish(articles))
+            self.loop.run_until_complete(self.publish_queued_items())
 
             # Yield control to other threads
             sleep(self.OPERATE_SLEEP_INTERVAL)
 
+    async def publish_queued_items(self):
+        """Publish all queued items."""
+        while self.publish_queue.qsize():
+            articles = self.publish_queue.get()
+            await self.publisher.publish(articles)
+
     def receiver(self, message):
         """Process incoming messages and coordinate response.
 
@@ -371,12 +385,19 @@ class WorkflowRuntimeServer:
         if executed.errors:
             errors: List[Any] = []
             for error in executed.errors:
+                LOG.error(error)
                 if hasattr(error, '__traceback__'):
                     import traceback
-                    errors.append({'error': {
-                        'message': str(error),
-                        'traceback': traceback.format_exception(
-                            error.__class__, error, error.__traceback__)}})
+                    formatted_tb = traceback.format_exception(
+                        type(error), error, error.__traceback__
+                    )
+                    LOG.error("".join(formatted_tb))
+                    errors.append({
+                        'error': {
+                            'message': str(error),
+                            'traceback': formatted_tb
+                        }
+                    })
                     continue
                 errors.append(getattr(error, 'message', None))
             return errors
