@@ -568,10 +568,7 @@ class TaskRemoteMgr:
         install_log_dir
     ):
         log_files = get_sorted_logs_by_time(install_log_dir, '*.log')
-        if log_files:
-            log_num = get_next_log_number(log_files[-1])
-        else:
-            log_num = '01'
+        log_num = get_next_log_number(log_files[-1]) if log_files else 1
         load_type = "start"
         if self.is_reload:
             load_type = "reload"
@@ -579,7 +576,7 @@ class TaskRemoteMgr:
         elif self.is_restart:
             load_type = "restart"
             self.is_restart = False  # reset marker
-        file_name = f"{log_num}-{load_type}-{install_target}.log"
+        file_name = f"{log_num:02d}-{load_type}-{install_target}.log"
         return file_name
 
     def _remote_init_items(self, comms_meth: CommsMeth):
