@@ -42,6 +42,8 @@ from cylc.flow.task_outputs import (
     TASK_OUTPUT_SUCCEEDED
 )
 
+from cylc.flow.cycling.iso8601 import ISO8601Point
+
 
 Fixture = Any
 
@@ -1395,6 +1397,46 @@ def test_zero_interval(
         assert not logged
 
 
+@pytest.mark.parametrize(
+    'icp, fcp_expr, expected_fcp',
+    [
+        ('2021-02-28', '+P1M+P1D', '2021-03-29'),
+        ('2019-02-28', '+P1D+P1M', '2019-04-01'),
+        ('2008-07-01', '+P1M-P1D', '2008-07-31'),
+        ('2004-07-01', '-P1D+P1M', '2004-07-30'),
+        ('1992-02-29', '+P1Y+P1M', '1993-03-28'),
+        ('1988-02-29', '+P1M+P1Y', '1989-03-29'),
+        ('1910-08-14', '+P2D-PT6H', '1910-08-15T18:00'),
+        ('1850-04-10', '+P1M-P1D+PT1H', '1850-05-09T01:00'),
+        pytest.param(
+            '1066-10-14', '+PT1H+PT1M', '1066-10-14T01:01',
+            marks=pytest.mark.xfail
+            # https://github.com/cylc/cylc-flow/issues/5047
+        ),
+    ]
+)
+def test_chain_expr(
+    icp: str, fcp_expr: str, expected_fcp: str, tmp_flow_config: Callable,
+):
+    """Test a "chain expression" final cycle point offset.
+
+    Note the order matters when "nominal" units (years, months) are used.
+    """
+    reg = 'osgiliath'
+    flow_file: Path = tmp_flow_config(reg, f"""
+        [scheduler]
+            UTC mode = True
+            allow implicit tasks = True
+        [scheduling]
+            initial cycle point = {icp}
+            final cycle point = {fcp_expr}
+            [[graph]]
+                P1D = faramir
+    """)
+    cfg = WorkflowConfig(reg, flow_file, options=ValidateOptions())
+    assert cfg.final_point == ISO8601Point(expected_fcp).standardise()
+
+
 @pytest.mark.parametrize(
     'runtime_cfg',
     (
