@@ -1412,6 +1412,28 @@ def test_remote_clean_cmd(
     assert constructed_cmd == ['clean', '--local-only', reg, *expected_args]
 
 
+def test_clean_top_level(tmp_run_dir: Callable):
+    """Test that cleaning last remaining run dir inside a workflow dir removes
+    the top level dir if it's empty (excluding _cylc-install)."""
+    # Setup
+    reg = 'blue/planet/run1'
+    run_dir: Path = tmp_run_dir(reg, installed=True, named=True)
+    cylc_install_dir = run_dir.parent / WorkflowFiles.Install.DIRNAME
+    assert cylc_install_dir.is_dir()
+    runN_symlink = run_dir.parent / WorkflowFiles.RUN_N
+    assert runN_symlink.exists()
+    # Test
+    clean(reg, run_dir)
+    assert not run_dir.parent.parent.exists()
+    # Now check that if the top level dir is not empty, it doesn't get removed
+    run_dir: Path = tmp_run_dir(reg, installed=True, named=True)
+    jellyfish_file = (run_dir.parent / 'jellyfish.txt')
+    jellyfish_file.touch()
+    clean(reg, run_dir)
+    assert cylc_install_dir.is_dir()
+    assert jellyfish_file.exists()
+
+
 def test_get_workflow_source_dir_numbered_run(tmp_path):
     """Test get_workflow_source_dir returns correct source for numbered run"""
     cylc_install_dir = (
@@ -1574,7 +1596,7 @@ def test_check_flow_file(
             "Both flow.cylc and suite.rc files are present in "
             f"{tmp_path}. Please remove one and try again. "
             "For more information visit: "
-            "https://cylc.github.io/cylc-doc/latest/html/7-to-8/summary.html"
+            "https://cylc.github.io/cylc-doc/stable/html/7-to-8/summary.html"
             "#backward-compatibility"
         )
 
@@ -1594,7 +1616,7 @@ def test_detect_both_flow_and_suite(tmp_path):
     assert str(exc.value) == (
         f"Both flow.cylc and suite.rc files are present in {tmp_path}. Please "
         "remove one and try again. For more information visit: "
-        "https://cylc.github.io/cylc-doc/latest/html/7-to-8/"
+        "https://cylc.github.io/cylc-doc/stable/html/7-to-8/"
         "summary.html#backward-compatibility"
     )
 
